Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1048)

Unified Diff: webkit/browser/fileapi/file_system_context.cc

Issue 18344013: fileapi: Rename FileSystemMountProvider to FileSystemBackend (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webkit/browser/fileapi/file_system_context.cc
diff --git a/webkit/browser/fileapi/file_system_context.cc b/webkit/browser/fileapi/file_system_context.cc
index 97f420570fa9bc1b9cd7477b5df64ee8d284099c..52b30515a84f7f1b087989f72f64d1dd011adf31 100644
--- a/webkit/browser/fileapi/file_system_context.cc
+++ b/webkit/browser/fileapi/file_system_context.cc
@@ -104,7 +104,7 @@ FileSystemContext::FileSystemContext(
ExternalMountPoints* external_mount_points,
quota::SpecialStoragePolicy* special_storage_policy,
quota::QuotaManagerProxy* quota_manager_proxy,
- ScopedVector<FileSystemMountPointProvider> additional_providers,
+ ScopedVector<FileSystemBackend> additional_providers,
kinuko 2013/07/04 07:12:23 Can you run s/additional_providers/additional_back
satorux1 2013/07/04 08:11:32 Done.
const base::FilePath& partition_path,
const FileSystemOptions& options)
: task_runners_(task_runners.Pass()),
@@ -131,7 +131,7 @@ FileSystemContext::FileSystemContext(
RegisterMountPointProvider(sandbox_provider_.get());
RegisterMountPointProvider(isolated_provider_.get());
kinuko 2013/07/04 07:12:23 Hmm... ok we'll do these remaining cleanup in our
satorux1 2013/07/04 08:11:32 Forgot about them. Renamed.
- for (ScopedVector<FileSystemMountPointProvider>::const_iterator iter =
+ for (ScopedVector<FileSystemBackend>::const_iterator iter =
additional_providers_.begin();
iter != additional_providers_.end(); ++iter) {
RegisterMountPointProvider(*iter);
@@ -154,7 +154,7 @@ bool FileSystemContext::DeleteDataForOriginOnFileThread(
for (MountPointProviderMap::iterator iter = provider_map_.begin();
iter != provider_map_.end();
++iter) {
- FileSystemMountPointProvider* provider = iter->second;
+ FileSystemBackend* provider = iter->second;
if (!provider->GetQuotaUtil())
continue;
if (provider->GetQuotaUtil()->DeleteOriginDataOnFileThread(
@@ -170,7 +170,7 @@ bool FileSystemContext::DeleteDataForOriginOnFileThread(
FileSystemQuotaUtil*
FileSystemContext::GetQuotaUtil(FileSystemType type) const {
- FileSystemMountPointProvider* mount_point_provider =
+ FileSystemBackend* mount_point_provider =
GetMountPointProvider(type);
if (!mount_point_provider)
return NULL;
@@ -179,7 +179,7 @@ FileSystemContext::GetQuotaUtil(FileSystemType type) const {
AsyncFileUtil* FileSystemContext::GetAsyncFileUtil(
FileSystemType type) const {
- FileSystemMountPointProvider* mount_point_provider =
+ FileSystemBackend* mount_point_provider =
GetMountPointProvider(type);
if (!mount_point_provider)
return NULL;
@@ -188,7 +188,7 @@ AsyncFileUtil* FileSystemContext::GetAsyncFileUtil(
FileSystemFileUtil* FileSystemContext::GetFileUtil(
FileSystemType type) const {
- FileSystemMountPointProvider* mount_point_provider =
+ FileSystemBackend* mount_point_provider =
GetMountPointProvider(type);
if (!mount_point_provider)
return NULL;
@@ -200,7 +200,7 @@ FileSystemContext::GetCopyOrMoveFileValidatorFactory(
FileSystemType type, base::PlatformFileError* error_code) const {
DCHECK(error_code);
*error_code = base::PLATFORM_FILE_OK;
- FileSystemMountPointProvider* mount_point_provider =
+ FileSystemBackend* mount_point_provider =
GetMountPointProvider(type);
if (!mount_point_provider)
return NULL;
@@ -208,7 +208,7 @@ FileSystemContext::GetCopyOrMoveFileValidatorFactory(
type, error_code);
}
-FileSystemMountPointProvider* FileSystemContext::GetMountPointProvider(
+FileSystemBackend* FileSystemContext::GetMountPointProvider(
FileSystemType type) const {
MountPointProviderMap::const_iterator found = provider_map_.find(type);
if (found != provider_map_.end())
@@ -226,13 +226,13 @@ const UpdateObserverList* FileSystemContext::GetUpdateObservers(
// Currently update observer is only available in SandboxMountPointProvider
// and TestMountPointProvider.
// TODO(kinuko): Probably GetUpdateObservers() virtual method should be
// added to FileSystemMountPointProvider interface and be called like
// other GetFoo() methods do.
if (sandbox_provider_->CanHandleType(type))
return sandbox_provider_->GetUpdateObservers(type);
if (type != kFileSystemTypeTest)
return NULL;
- FileSystemMountPointProvider* mount_point_provider =
+ FileSystemBackend* mount_point_provider =
GetMountPointProvider(type);
return static_cast<TestMountPointProvider*>(
mount_point_provider)->GetUpdateObservers(type);
@@ -254,9 +254,9 @@ void FileSystemContext::GetFileSystemTypes(
types->push_back(iter->first);
}
-ExternalFileSystemMountPointProvider*
+ExternalFileSystemBackend*
FileSystemContext::external_provider() const {
- return static_cast<ExternalFileSystemMountPointProvider*>(
+ return static_cast<ExternalFileSystemBackend*>(
GetMountPointProvider(kFileSystemTypeExternal));
}
@@ -267,7 +267,7 @@ void FileSystemContext::OpenFileSystem(
const OpenFileSystemCallback& callback) {
DCHECK(!callback.is_null());
- FileSystemMountPointProvider* mount_point_provider =
+ FileSystemBackend* mount_point_provider =
GetMountPointProvider(type);
if (!mount_point_provider) {
callback.Run(base::PLATFORM_FILE_ERROR_SECURITY, std::string(), GURL());
@@ -291,7 +291,7 @@ void FileSystemContext::DeleteFileSystem(
FileSystemType type,
const DeleteFileSystemCallback& callback) {
DCHECK(origin_url == origin_url.GetOrigin());
- FileSystemMountPointProvider* mount_point_provider =
+ FileSystemBackend* mount_point_provider =
GetMountPointProvider(type);
if (!mount_point_provider) {
callback.Run(base::PLATFORM_FILE_ERROR_SECURITY);
@@ -308,7 +308,7 @@ FileSystemContext::CreateFileStreamReader(
const base::Time& expected_modification_time) {
if (!url.is_valid())
return scoped_ptr<webkit_blob::FileStreamReader>();
- FileSystemMountPointProvider* mount_point_provider =
+ FileSystemBackend* mount_point_provider =
GetMountPointProvider(url.type());
if (!mount_point_provider)
return scoped_ptr<webkit_blob::FileStreamReader>();
@@ -321,7 +321,7 @@ scoped_ptr<FileStreamWriter> FileSystemContext::CreateFileStreamWriter(
int64 offset) {
if (!url.is_valid())
return scoped_ptr<FileStreamWriter>();
- FileSystemMountPointProvider* mount_point_provider =
+ FileSystemBackend* mount_point_provider =
GetMountPointProvider(url.type());
if (!mount_point_provider)
return scoped_ptr<FileStreamWriter>();
@@ -386,7 +386,7 @@ FileSystemOperation* FileSystemContext::CreateFileSystemOperation(
return NULL;
}
- FileSystemMountPointProvider* mount_point_provider =
+ FileSystemBackend* mount_point_provider =
GetMountPointProvider(url.type());
if (!mount_point_provider) {
if (error_code)
@@ -432,7 +432,7 @@ FileSystemURL FileSystemContext::CrackFileSystemURL(
}
void FileSystemContext::RegisterMountPointProvider(
- FileSystemMountPointProvider* provider) {
+ FileSystemBackend* provider) {
const FileSystemType mount_types[] = {
kFileSystemTypeTemporary,
kFileSystemTypePersistent,
@@ -226,13 +226,13 @@ const UpdateObserverList* FileSystemContext::GetUpdateObservers(
// and TestMountPointProvider.
// TODO(kinuko): Probably GetUpdateObservers() virtual method should be
- // added to FileSystemMountPointProvider interface and be called like
+ // added to FileSystemBackend interface and be called like
// other GetFoo() methods do.
if (sandbox_provider_->CanHandleType(type))

Powered by Google App Engine
This is Rietveld 408576698